@@ -1181,7 +1181,10 @@ void NeoChatRoom::loadPinnedMessage()
         connection()->callApi<GetOneRoomEventJob>(id(), mostRecentEventId).then([this](const auto &job) {
             auto event = fromJson<event_ptr_tt<RoomEvent>>(job->jsonData());
             if (auto encEv = eventCast<EncryptedEvent>(event.get())) {
-                event = decryptMessage(*encEv);
+                auto decryptedMessage = decryptMessage(*encEv);
+                if (decryptedMessage) {
+                    event = std::move(decryptedMessage);
+                }
             }
             m_pinnedMessage = EventHandler::richBody(this, event.get());
             Q_EMIT pinnedMessageChanged();
@@ -1649,6 +1652,12 @@ void NeoChatRoom::downloadEventFromServer(const QString &eventId)
                 }
 
                 event_ptr_tt<RoomEvent> event = fromJson<event_ptr_tt<RoomEvent>>(job->jsonData());
+                if (auto encEv = eventCast<EncryptedEvent>(event.get())) {
+                    auto decryptedEvent = decryptMessage(*encEv);
+                    if (decryptedEvent) {
+                        event = std::move(decryptedEvent);
+                    }
+                }
                 m_extraEvents.push_back(std::move(event));
                 Q_EMIT extraEventLoaded(eventId);
             },
