@@ -12,6 +12,7 @@
 
 #include <QCoroTask>
 
+#include "enums/chatbartype.h"
 #include "enums/messagetype.h"
 #include "enums/pushrule.h"
 #include "events/pollevent.h"
@@ -202,13 +203,18 @@ class NeoChatRoom : public Quotient::Room
      */
     Q_PROPERTY(QString invitingUserId READ invitingUserId NOTIFY baseStateLoaded)
 
+    /**
+     * @brief The most recently pinned message in the room.
+     */
+    Q_PROPERTY(QString pinnedMessage READ pinnedMessage NOTIFY pinnedMessageChanged)
+
 public:
     explicit NeoChatRoom(Quotient::Connection *connection, QString roomId, Quotient::JoinState joinState = {});
 
     bool visible() const;
     void setVisible(bool visible);
 
-    [[nodiscard]] QDateTime lastActiveTime();
+    [[nodiscard]] QDateTime lastActiveTime() const;
 
     /**
      * @brief Get the last interesting event.
@@ -484,6 +490,8 @@ public:
 
     ChatBarCache *threadCache() const;
 
+    ChatBarCache *cacheForType(ChatBarType::Type type) const;
+
     /**
      * @brief Reply to the last message sent in the timeline.
      *
@@ -544,7 +552,15 @@ public:
      * @brief Return the cached file transfer information for the event.
      *
      * If we downloaded the file previously, return a struct with Completed status
-     * and the local file path stored in KSharedCOnfig
+     * and the local file path stored in KSharedConfig
+     */
+    Quotient::FileTransferInfo cachedFileTransferInfo(const QString &eventId) const;
+
+    /**
+     * @brief Return the cached file transfer information for the event.
+     *
+     * If we downloaded the file previously, return a struct with Completed status
+     * and the local file path stored in KSharedConfig
      */
     Quotient::FileTransferInfo cachedFileTransferInfo(const Quotient::RoomEvent *event) const;
 
@@ -589,6 +605,23 @@ public:
 
     static void setHiddenFilter(std::function<bool(const Quotient::RoomEvent *)> hiddenFilter);
 
+    /**
+     * @brief Whether this room has a room version where the creator is treated as having an ultimate power level
+     *
+     * For unusual room versions, this information might be wrong.
+     */
+    Q_INVOKABLE bool roomCreatorHasUltimatePowerLevel() const;
+
+    /**
+     * @brief Whether this user is considered a creator of this room. Only applies to post-v12 rooms.
+     */
+    bool isCreator(const QString &userId) const;
+
+    /**
+     * @return The most recent pinned message in the room.
+     */
+    QString pinnedMessage() const;
+
 private:
     bool m_visible = false;
 
@@ -621,6 +654,8 @@ private:
 
     std::unordered_map<QString, std::unique_ptr<NeochatRoomMember>> m_memberObjects;
     static std::function<bool(const Quotient::RoomEvent *)> m_hiddenFilter;
+    QString m_pinnedMessage;
+    void loadPinnedMessage();
 
 private Q_SLOTS:
     void updatePushNotificationState(QString type);
@@ -651,6 +686,7 @@ Q_SIGNALS:
     void extraEventLoaded(const QString &eventId);
     void extraEventNotFound(const QString &eventId);
     void inviteTimestampChanged();
+    void pinnedMessageChanged();
 
     /**
      * @brief Request a message be shown to the user of the given type.
